@@ -61,10 +61,14 @@ class GARCHdiff_treeX2(svol_model):
 class GARCHdiff_grid(svol_model):
     def __init__( self, series,dt, model, method,options ):
         super().__init__(series,dt, model, method,options)
+        return
+
+    def _init_d(self):
 
         mu=0.0
         sigma=0.1
-        (mu,sigma)=meanvariance(np.array(self.series),dt)
+        if( len(self.series)>1 ):
+            (mu,sigma)=meanvariance(np.array(self.series),self.dt)
         rho=0.0
         alpha=2.0
         xi=1.0
@@ -79,23 +83,98 @@ class GARCHdiff_grid(svol_model):
 #                 [hmu, hsigma, rho, alpha, xi,u0]
         self.workingpars_bounds=[(-0.5,0.5), (0.05, 0.5), (-0.9,0.9), (alpha_min, 20.0), (0.1, 4.0)]
 
+        if 'init' in self.options:
+            self.initpars_reporting(self.options['init'])
+
 # precalculate anything that can absolutely be reused:
 #TODO: ugly!!
         Nret=self.Nobs-1
-        self.yasset=np.log( self.series[1:Nret+1]/self.series[0:Nret] )
-        self.upath=np.zeros(self.Nobs)
+        if(Nret>0):
+            self.yasset=np.log( self.series[1:Nret+1]/self.series[0:Nret] )
+            self.upath=np.zeros(self.Nobs)
 
         return
 
     def initpars_reporting(self,pardict):
-# this alters self.working_pars, so make sure it's called after they are init'd
+
+        mu=self.workingpars[0] 
+        sigma=self.workingpars[1]
+        rho=self.workingpars[2]
+        alpha=self.workingpars[3] 
+        xi=self.workingpars[4]
+
+        theta=sigma*sigma
+        eta=xi*sigma
+
+        for x in pardict:
+            if( x=='mu' ):
+                mu=pardict[x]
+            if( x=='theta' ):
+                theta=pardict[x]
+            if( x=='rho' ):
+                rho=pardict[x]
+            if( x=='alpha' ):
+                alpha=pardict[x]
+            if( x=='eta' ):
+                eta=pardict[x]
+# this sucks: the model needs a v0, but the optimiation doesn't...
+            if( x=='v0' ):
+                v0=pardict[x]
+
+        sigma=np.sqrt(theta)
+        xi=eta/sigma
+
+        self.workingpars[0]=mu
+        self.workingpars[1]=sigma
+        self.workingpars[2]=rho
+        self.workingpars[3]=alpha
+        self.workingpars[4]=xi
+        self.frozen_u0=v0/theta
         return
 
     def get_structure(self):
-        return '','',[],0
+        assetname='asset'
+        variancename='variance'
+
+        sigma=self.workingpars[1]
+        rho=self.workingpars[2]
+
+        corrmatrix=np.array([[1.0,rho],[rho,1.0]])
+#TODO: best choice based on pars?
+        Nperstep=16
+
+        assetval=1.0
+        varianceval=self.frozen_u0*sigma*sigma
+
+        return assetname,assetval,variancename,varianceval,corrmatrix,Nperstep
     
-    def sim_step(self):
-        return 
+    def sim_step(self,asset,variance,Zs):
+
+        mu=self.workingpars[0] 
+        sigma=self.workingpars[1]
+#        rho=self.workingpars[2]
+        alpha=self.workingpars[3] 
+        xi=self.workingpars[4]
+
+        theta=sigma*sigma
+        eta=xi*sigma
+        
+        Nperstep=np.shape(Zs)[1]
+        sim_asset=np.log(asset)
+        sim_variance =variance       
+        
+        dt=self.dt/Nperstep
+        vmin=1.0e-12
+        
+        for cc in range(0,Nperstep):
+            sim_asset+=(mu-0.5*sim_variance)*dt+np.sqrt(sim_variance*dt)*Zs[0,cc,:]
+#            sim_variance=np.power(np.sqrt(sim_variance)+0.5*eta*np.sqrt(dt)*Zs[1,cc,:],2)+alpha*(theta-sim_variance)*dt-eta*eta*dt/4.0
+# euler only
+            sim_variance+=alpha*(theta-sim_variance)*dt+eta*sim_variance*np.sqrt(dt)*Zs[1,cc,:]
+            sim_variance=np.maximum(sim_variance,vmin)
+
+        sim_asset=np.exp(sim_asset)
+        return sim_asset,sim_variance
 
     def get_reportingpars(self):
         super().get_reportingpars()
