@@ -15,10 +15,14 @@ from svolfit.models.Heston_utils import Heston_lncondassetprob,Heston_griddefs,H
 class Heston_tree(svol_model):
     def __init__( self, series,dt, model, method,options ):
         super().__init__(series,dt, model, method,options)
+        return
+
+    def _init_d(self):
 
         mu=0.0
         sigma=0.1
-        (mu,sigma)=meanvariance(np.array(self.series),dt)
+        if( len(self.series) > 1 ):
+            (mu,sigma)=meanvariance(np.array(self.series),self.dt)
         rho=0.0
         alpha=2.0
         xi=1.0
@@ -34,8 +38,8 @@ class Heston_tree(svol_model):
 #                 [hmu, hsigma, rho, alpha, xi,u0]
         self.workingpars_bounds=[(-0.5,0.5), (0.05, 0.5), (-0.9,0.9), (alpha_min, 20.0), (0.1, 3.5),(0.1,3.0)]
 
-        if 'init' in options:
-            self.initpars_reporting(options['init'])
+        if 'init' in self.options:
+            self.initpars_reporting(self.options['init'])
 
 # precalculate anything that can absolutely be reused:
 #TODO: ugly!!
@@ -123,7 +127,7 @@ class Heston_tree(svol_model):
 
         mu=self.workingpars[0] 
         sigma=self.workingpars[1]
-        rho=self.workingpars[2]
+#        rho=self.workingpars[2]
         alpha=self.workingpars[3] 
         xi=self.workingpars[4]
 
@@ -459,10 +463,14 @@ class Heston_tree(svol_model):
 class Heston_treeX2(svol_model):
     def __init__( self, series,dt, model, method,options ):
         super().__init__(series,dt, model, method,options)
+        return
+
+    def _init_d(self):
 
         mu=0.0
         sigma=0.1
-        (mu,sigma)=meanvariance(np.array(self.series),self.dt)
+        if( len(self.series) > 1 ):
+            (mu,sigma)=meanvariance(np.array(self.series),self.dt)
         rho=0.0
         alpha=2.0
         xi=1.0
@@ -479,8 +487,8 @@ class Heston_treeX2(svol_model):
 #                 [hmu, hsigma, rho, alpha, xi,u0]
         self.workingpars_bounds=[(-0.5,0.5), (0.05, 0.5), (-0.9,0.9), (alpha_min, 20.0), (0.1, 4.5),(0.1,3.0)]
 
-        if 'init' in options:
-            self.initpars_reporting(options['init'])
+        if 'init' in self.options:
+            self.initpars_reporting(self.options['init'])
 
 # precalculate anything that can absolutely be reused:
 #TODO: ugly!!
@@ -568,7 +576,7 @@ class Heston_treeX2(svol_model):
 
         mu=self.workingpars[0] 
         sigma=self.workingpars[1]
-        rho=self.workingpars[2]
+#        rho=self.workingpars[2]
         alpha=self.workingpars[3] 
         xi=self.workingpars[4]
 
@@ -968,10 +976,14 @@ class Heston_treeX2(svol_model):
 class Heston_grid(svol_model):
     def __init__( self, series,dt, model, method,options ):
         super().__init__(series,dt, model, method,options)
+        return
+
+    def _init_d(self):
 
         mu=0.0
         sigma=0.1
-        (mu,sigma)=meanvariance(np.array(self.series),dt)
+        if( len(self.series) > 1 ):
+            (mu,sigma)=meanvariance(np.array(self.series),self.dt)
         rho=0.0
         alpha=2.0
         xi=1.0
@@ -986,8 +998,8 @@ class Heston_grid(svol_model):
 #                 [hmu, hsigma, rho, alpha, xi,u0]
         self.workingpars_bounds=[(-0.5,0.5), (0.05, 0.5), (-0.9,0.9), (alpha_min, 20.0), (0.1, 4.0)]
 
-        if 'init' in options:
-            self.initpars_reporting(options['init'])
+        if 'init' in self.options:
+            self.initpars_reporting(self.options['init'])
 
 # precalculate anything that can absolutely be reused:
 #TODO: ugly!!
