@@ -4,14 +4,14 @@ from math import factorial
 
 #-------------------------------------------------
 
-def MertonJD_lncondassetprob(y,dt,mu,sigma,jumpintensity,jumpmean,jumpvolatility,lncp):
+def MertonJD_lncondassetprob(y,dt,mu,sigma,lamb,gamm,omeg,lncp):
 
 # calc probabilities first to determine the number of terms needed:    
     lnprobtol=np.log(1.0e-10)
     Njump=11
     j_lnprobs=np.zeros(Njump)
-    j_lnprobs[0]=-jumpintensity*dt
-    j_lnprobs[1:Njump]=np.array([-jumpintensity*dt+cj*np.log(jumpintensity*dt)-np.log(factorial(cj)) for cj in range(1,Njump)])
+    j_lnprobs[0]=-lamb*dt
+    j_lnprobs[1:Njump]=np.array([-lamb*dt+cj*np.log(lamb*dt)-np.log(factorial(cj)) for cj in range(1,Njump)])
     Njump=np.argmax(j_lnprobs<=lnprobtol)
     j_lnprobs=j_lnprobs[0:Njump]
     j_lnprobs-=splse(j_lnprobs)
@@ -25,12 +25,12 @@ def MertonJD_lncondassetprob(y,dt,mu,sigma,jumpintensity,jumpmean,jumpvolatility
     Ngrid=1
 
     j_nj = np.array(range(0,Njump))
-    j_vol_tmp = np.sqrt(np.add.outer(vol_tmp*vol_tmp,jumpvolatility*jumpvolatility*j_nj))
+    j_vol_tmp = np.sqrt(np.add.outer(vol_tmp*vol_tmp,omeg*omeg*j_nj))
    
     j_yy_tmp=np.zeros((Nobs,Ngrid,Njump))
     j_yy_tmp[:,:,:]=np.tile(y,(Njump,Ngrid,1)).T
     j_yy_tmp[:,:,:]-=np.tile(np.tile(coeff_dt,(Nobs,1)).T,(Njump,1,1)).T
-    j_yy_tmp[:,:,:]-=np.tile(jumpmean*j_nj,(Nobs,Ngrid,1))
+    j_yy_tmp[:,:,:]-=np.tile(gamm*j_nj,(Nobs,Ngrid,1))
     j_yy_tmp[:,:,:]/=np.tile(j_vol_tmp,(Nobs,1,1))
     
 # log-probs    
