@@ -5,15 +5,18 @@ class Template(svol_model):
         super().__init__(series,dt, model, method,options)
         return
 
+    def _init_d(self):
+        return
+
     def initpars_reporting(self,pardict):
 # this alters self.working_pars, so make sure it's called after they are init'd
         return
 
     def get_structure(self):
-        return '','',[],0
+        return '',0.0,'',0.0,[],0
     
-    def sim_step(self):
-        return 
+    def sim_step(self,asset,variance,Zs):
+        return [],[]
 
     def get_reportingpars(self):
         super().get_reportingpars()
