@@ -9,6 +9,7 @@ class svol_model(ABC):
         self.dt=dt
         self.model=model
         self.method=method
+        self.options=options.copy()
 
         self.Nobs=len(self.series)
 
@@ -27,6 +28,8 @@ class svol_model(ABC):
 # for multithreaded grad calcs
         self.gradmodels=[]
         
+        self._init_d()
+        
         return
 
 # generic abstract method -- needs to be implemented by concrete class
@@ -35,6 +38,11 @@ class svol_model(ABC):
 #        accrued=self.calc()
 #        return accrued
 
+# move all derived class initing to separate method and call automatically:
+    @abstractmethod
+    def _init_d(self):
+        return
+
     @abstractmethod
     def initpars_reporting(self,pardict):
         return
