@@ -22,90 +22,106 @@ models=[]
 methods=[]
 testpars=[]
 
+cc=0
 models.append('Template')
 methods.append('tree')
 testpars.append(
     {}
     )
 
+cc=1
 models.append('GBM')
 methods.append('analytic')
 testpars.append(
     {'rep_mu': 0.01542585774471747, 'rep_sigma': 0.05512169247825324, 'misc_theta': 0.00303840098166712, 'misc_v0': 0.00303840098166712, 'misc_vT': 0.00303840098166712, 'misc_GBM_mu': 0.016652991518886752, 'misc_GBM_sigma': 0.055184064089833784}
     )
+cc=2
 models.append('HestonNandi')
 methods.append('v')
 testpars.append(
-    {'rep_mu': -0.5, 'rep_theta': 0.09116625083360252, 'rep_rho': -1.0, 'rep_alpha': 0.6666666666666694, 'rep_eta': 0.030193749491191885, 'misc_q': 133.3333333332132, 'rep_v0': 0.00912574170844385, 'rep_vT': 0.05810649317126487}
+    {'rep_mu': 0.49999999999999994, 'rep_theta': 0.0054656717131093486, 'misc_rho': -1.0, 'rep_alpha': 19.999999999999986, 'rep_eta': 0.007393018134097433, 'misc_q': 3999.9999999999964, 'rep_v0': 0.005469789922271396, 'rep_vT': 0.005594363384161544}
     )
+cc=3
 models.append('MertonJD')
 methods.append('grid')
 testpars.append(
-    {'rep_mu': 0.03347013368019067, 'rep_theta': 0.0028511638994011615, 'misc_v0': 0.0028511638994011615, 'misc_vT': 0.0028511638994011615, 'rep_jumpintensity': 1.5726619477670725, 'rep_jumpmean': -0.010785947829484681, 'rep_jumpvolatility': 0.0021}
+    {'rep_mu': 0.034241223633602776, 'rep_sigma': 0.05139082648785998, 'misc_theta': 0.002641017047105331, 'misc_v0': 0.002641017047105331, 'misc_vT': 0.002641017047105331, 'rep_lambda': 19.99736439726318, 'rep_gamma': -0.0010686514095786003, 'rep_omega': 0.004691971323224507}
     )
+cc=4
 models.append('PureJump')
 methods.append('grid')
 testpars.append(
-    {'rep_mu': 0.37784980841053506, 'misc_v0': 1.0, 'misc_vT': 1.0, 'rep_jumpintensity': 355.9409162865344, 'rep_jumpmean': -0.0008139495440064259, 'rep_jumpvolatility': 0.0024720326241349736}
+    {'rep_mu': 0.37784034161927893, 'rep_lambda': 355.94092239176194, 'rep_gamma': -0.0008140312476703669, 'rep_omega': 0.0024720947028657337}
     )
 
+cc=5
 models.append('Heston')
 methods.append('grid')
 testpars.append(
     {'rep_mu': 0.031598578372465116, 'rep_theta': 0.0031625449896207154, 'rep_rho': 0.3783686034802998, 'rep_alpha': 3.2654036384020606, 'rep_eta': 0.03593784165348757, 'misc_q': 15.99188281772672, 'rep_v0': 0.0037384545754480065, 'rep_vT': 0.0029216493740896183}
     )
+cc=6
 models.append('Heston')
 methods.append('tree')
 testpars.append(
     {'rep_mu': 0.03055071749984695, 'rep_theta': 0.003132865268790383, 'rep_rho': 0.3607679427218266, 'rep_alpha': 4.233093285968648, 'rep_eta': 0.04028996174265257, 'misc_q': 16.33939015419114, 'rep_v0': 0.004270168559368956, 'rep_vT': 0.002914018962491343}
     )
+cc=7
 models.append('Heston')
 methods.append('treeX2')
 testpars.append(
     {'rep_mu': 0.03411855836869871, 'rep_theta': 0.003156592911928414, 'rep_rho': 0.48495286998294873, 'rep_alpha': 3.3384898883577567, 'rep_eta': 0.03799206422445619, 'misc_q': 14.602017222890494, 'rep_v0': 0.004408771967202047, 'rep_vT': 0.0030085719536116946}
     )
 
+cc=8
 models.append('Bates')
 methods.append('grid')
 testpars.append(
-    {'rep_mu': 0.03629507199787237, 'rep_theta': 0.002788222179037243, 'rep_rho': 0.6554003444511729, 'rep_alpha': 2.1565325673898528, 'rep_eta': 0.01746580072521935, 'rep_jumpintensity': 9.881484212656488, 'rep_jumpmean': -0.000989518647430321, 'rep_jumpvolatility': 0.005626334604352059, 'misc_q': 39.4217947715374, 'rep_v0': 0.003011643103236992, 'rep_vT': 0.002917529256260836}
+    {'rep_mu': 0.03422833361276888, 'rep_theta': 0.0027382181331400525, 'rep_rho': 0.6529567921776389, 'rep_alpha': 3.6955486226220393, 'rep_eta': 0.0217535938499926, 'rep_lambda': 10.40610204852361, 'rep_gamma': -0.0009817805020765262, 'rep_omega': 0.005687613305845231, 'misc_q': 42.767604667203855, 'rep_v0': 0.003044847932439241, 'rep_vT': 0.002812925126122225}
     )
+cc=9
 models.append('Bates')
 methods.append('tree')
 testpars.append(
-    {'rep_mu': 0.03512465101845133, 'rep_theta': 0.0029279402427590225, 'rep_rho': 0.3498022589163152, 'rep_alpha': 6.695152107431421, 'rep_eta': 0.03315143313510526, 'rep_jumpintensity': 1.089966313235409, 'rep_jumpmean': -0.011001221107887366, 'rep_jumpvolatility': 0.002, 'misc_q': 35.673690272306715, 'rep_v0': 0.003414465729620618, 'rep_vT': 0.0029279402436796905}
+    {'rep_mu': 0.03328002173593035, 'rep_theta': 0.0026031493337724657, 'rep_rho': 0.6585982546638651, 'rep_alpha': 10.985996928482411, 'rep_eta': 0.028655676721350994, 'rep_lambda': 18.61790067418388, 'rep_gamma': -0.0007515905135513218, 'rep_omega': 0.004813668154764279, 'misc_q': 69.65418477428888, 'rep_v0': 0.002654347209891931, 'rep_vT': 0.0027475755837688136}
     )
+cc=10
 models.append('Bates')
 methods.append('treeX2')
 testpars.append(
-    {'rep_mu': 0.03389436563426533, 'rep_theta': 0.003153236308380956, 'rep_rho': 0.4819321411707735, 'rep_alpha': 3.3922821186565333, 'rep_eta': 0.0381677327571819, 'rep_jumpintensity': 7.43329726125106e-16, 'rep_jumpmean': 0.02101471531707188, 'rep_jumpvolatility': 0.006994325019346036, 'misc_q': 14.685399043407097, 'rep_v0': 0.004401734819103718, 'rep_vT': 0.00300461829960417}
+    {'rep_mu': 0.019484937625758654, 'rep_theta': 0.0025000000000000005, 'rep_rho': 0.8566802984507665, 'rep_alpha': 20.0, 'rep_eta': 0.024300232437840134, 'rep_lambda': 21.509548490911214, 'rep_gamma': -0.0005722540153894941, 'rep_omega': 0.0047449863010841095, 'misc_q': 169.34763833224156, 'rep_v0': 0.0025080995497863677, 'rep_vT': 0.002670570783168483}
     )
 
+cc=11
 models.append('H32')
 methods.append('grid')
 testpars.append(
-    {'rep_mu': 0.035319851283899334, 'rep_theta': 0.0029947032665145605, 'rep_rho': 0.4464775392335281, 'rep_alpha': 2.075655179989457, 'rep_eta': 0.03353306401273929, 'misc_q': 11.055859822435137, 'rep_v0': 0.00430649913663229, 'rep_vT': 0.0029017053006185484}
+    {'rep_mu': 0.03531985140108286, 'rep_theta': 0.0036560879044557114, 'rep_rho': 0.4464775394228347, 'rep_alpha': 567.7257315252865, 'rep_eta': 11.197458003023403, 'misc_q': 11.055859788118669, 'misc_theta': 333.92290005932324, 'misc_eta': 11.197458003023403, 'rep_v0': 0.004306499124928703, 'rep_vT': 0.0029017052927327084}
     )
 
+cc=12
 models.append('B32')
 methods.append('grid')
 testpars.append(
-    {'rep_mu': 0.03531638498310953, 'rep_theta': 0.0029946453221853095, 'rep_rho': 0.446515888178378, 'rep_alpha': 2.075661338592072, 'rep_eta': 0.03353400430578841, 'rep_jumpintensity': 0.0015438467976698468, 'rep_jumpmean': 0.00023267361580830406, 'rep_jumpvolatility': 0.0031015640884938865, 'misc_q': 11.055058712612349, 'rep_v0': 0.004306091148023715, 'rep_vT': 0.002901430399203145}
+    {'rep_mu': 0.035316384905647216, 'rep_theta': 0.002994645321556647, 'rep_rho': 0.4465158873830807, 'rep_alpha': 2.075661338529547, 'rep_eta': 0.03353400423955311, 'rep_lambda': 0.001543846573955615, 'rep_gamma': 0.0002326736137745283, 'rep_omega': 0.003101563825045725, 'misc_q': 11.055058753629762, 'rep_v0': 0.004306091163224677, 'rep_vT': 0.002901430409445504}
     )
 
+cc=13
 models.append('GARCHdiff')
 methods.append('grid')
 testpars.append(
     {'rep_mu': 0.03042537186423229, 'rep_theta': 0.003169068293374862, 'rep_rho': 0.32992493777168147, 'rep_alpha': 3.697982718742663, 'rep_eta': 0.7331282453343007, 'misc_q': 13.760523902903858, 'rep_v0': 0.004275322841112933, 'rep_vT': 0.002897869549584506}
     )
 
+cc=14
 models.append('GARCHjdiff')
 methods.append('grid')
 testpars.append(
-    {'rep_mu': 0.03365915250373231, 'rep_theta': 0.002825696048736639, 'rep_rho': 0.5131999368186246, 'rep_alpha': 2.1084405116735807, 'rep_eta': 0.37217254460500154, 'rep_jumpintensity': 9.866935536366924, 'rep_jumpmean': -0.0009029963045800695, 'rep_jumpvolatility': 0.005420733639371999, 'misc_q': 30.44406806394848, 'rep_v0': 0.0033774685556112387, 'rep_vT': 0.002770604300314069}
+    {'rep_mu': 0.0336612712350063, 'rep_theta': 0.00282576813071708, 'rep_rho': 0.5132488597550273, 'rep_alpha': 2.108449201909646, 'rep_eta': 0.37211176066711865, 'rep_jumpintensity': 9.866931505831824, 'rep_jumpmean': -0.0009034060922315556, 'rep_jumpvolatility': 0.005422464131795289, 'misc_q': 30.454140389054718, 'rep_v0': 0.0033744381195861097, 'rep_vT': 0.0027682060213376834}
     )
 
 #for cc in range(0,len(models)):
+#for cc in [8,9,10,11,12,14]:
 #    print(models[cc]+' '+methods[cc])
 #    (pars,junk)=svolfit( series, dt, model=models[cc], method = methods[cc] )
 #    print(pars)
